@@ -13,8 +13,6 @@
 
 #include "mp3info.h"
 
-extern char *typegenre [128];
-
 
 /*
  * Check if Break is given, and if so, clean term and exit, else pad the input.
@@ -45,17 +43,17 @@ char *curs_addparam(WINDOW *win, int line, int length, char *buf) {
 
 void tagedit_curs(char *filename, int filenum, int fileoutof, struct id3tag *tag) {
 WINDOW *mainwin;
-   char line[50], *genre, genre_text[30];
-   unsigned int genre_num;
+   char line[50], track_text[4], *genre, genre_text[30];
+   unsigned int track_num, genre_num;
    line[0]='\0';
 
    initscr(); cbreak(); noecho();
    nonl();
-   mainwin = newwin(8,COLS,5,0);
+   mainwin = newwin(9,COLS,5,0);
    intrflush(mainwin, FALSE);
    keypad(mainwin, TRUE);
    CenterText(1,VERSION);
-   CenterText(2,"Ricardo Cerqueira <rmc@rccn.net>, 2000");
+/*   CenterText(2,"by Ricardo Cerqueira (C)2000"); */
 #ifdef HAVE_TOUCHWIN
    touchwin(mainwin);
 #endif
@@ -70,7 +68,14 @@ WINDOW *mainwin;
    wprintw(mainwin,"Year:          %s",tag->year);
    wmove(mainwin,5,1); 
    wprintw(mainwin,"Comment:       %s",tag->comment);
-   wmove(mainwin,6,1);
+   wmove(mainwin,6,1); 
+   if(tag->track[0] != '\0') {
+	sprintf(track_text,"%d",tag->track[0]);
+   } else {
+	track_text[0]='\0';
+   }
+   wprintw(mainwin,"Track:         %s",track_text);
+   wmove(mainwin,7,1);
    if(tag->genre[0] < 127) {
 	genre=typegenre[tag->genre[0]];
    } else {
@@ -78,9 +83,9 @@ WINDOW *mainwin;
    }
    strcpy(genre_text,genre);
    wprintw(mainwin,"Genre:         %s",genre);
-   wmove(mainwin,7,4);
+   wmove(mainwin,8,4);
    wprintw(mainwin," (%d/%d) %s ",filenum,fileoutof,filename);
-   wmove(mainwin,7,COLS-22);
+   wmove(mainwin,8,COLS-22);
    wprintw(mainwin," Press ^C to quit ");
    refresh();
    echo();
@@ -95,8 +100,17 @@ WINDOW *mainwin;
    curs_addparam(mainwin,5,30,line);
    strncpy(tag->comment,line,strlen(line));
    curs_addparam(mainwin,6,30,line);
+   strncpy(track_text,line,strlen(line) + (strlen(line) < strlen (track_text) ? 0 : 1));
+/*   strncpy(track_text,line,3); */
+   curs_addparam(mainwin,7,30,line);
    strncpy(genre_text,line,strlen(line) + (strlen(line) < strlen (genre_text) ? 0 : 1));
+
    endwin();
+   if((track_num=atoi(track_text)) < 256) {
+	tag->track[0] = (unsigned char) track_num;
+   } else {
+	printf("ERROR - '%s' is not a valid track number.\n",track_text);
+   }
    if((genre_num=get_genre(genre_text)) < 256) {
 	tag->genre[0] = (unsigned char) genre_num;
    } else {
