@@ -20,6 +20,7 @@ struct id3tag {
 	char album[31];
 	char year[5];
 	char comment[31];
+	unsigned char track[1];
 	unsigned char genre[1];
 };
 
@@ -30,7 +31,7 @@ char *curs_addparam(WINDOW *win, int line, int length, char *buf);
 void buildtag(char *buf, struct id3tag *tag);
 void display_help();
 void view_tag(char *filename,struct id3tag *tag);
-void display_genres(void);
+void display_genres(int alphagenreindex[],char *typegenre[]);
 unsigned int get_genre (char *genre);
 
 
